pub struct EmmyrcGmod {Show 15 fields
pub enabled: bool,
pub default_realm: EmmyrcGmodRealm,
pub scripted_class_scopes: EmmyrcGmodScriptedClassScopes,
pub hook_mappings: EmmyrcGmodHookMappings,
pub network: EmmyrcGmodNetwork,
pub vgui: EmmyrcGmodVgui,
pub outline: EmmyrcGmodOutline,
pub file_param_defaults: HashMap<String, String>,
pub detect_realm_from_filename: Option<bool>,
pub detect_realm_from_calls: Option<bool>,
pub infer_dynamic_fields: bool,
pub dynamic_fields_global: bool,
pub annotations_path: Option<String>,
pub auto_load_annotations: Option<bool>,
pub template_path: Option<String>,
}Fields
enabled: booldefault_realm: EmmyrcGmodRealmscripted_class_scopes: EmmyrcGmodScriptedClassScopeshook_mappings: EmmyrcGmodHookMappingsnetwork: EmmyrcGmodNetworkvgui: EmmyrcGmodVguioutline: EmmyrcGmodOutlinefile_param_defaults: HashMap<String, String>Parameter-name to type-name fallbacks for otherwise unresolved params.
detect_realm_from_filename: Option<bool>detect_realm_from_calls: Option<bool>infer_dynamic_fields: booldynamic_fields_global: boolannotations_path: Option<String>Path to GMod annotations to load as core library.
When set to empty string or not provided, uses VSCode extension’s auto-downloaded annotations (if enabled).
Set to explicit path to override, or use autoLoadAnnotations: false in .emmyrc to disable entirely.
auto_load_annotations: Option<bool>Disable auto-loading of annotations (from VSCode or default path). This takes precedence over extension settings.
template_path: Option<String>Path to a folder containing custom GLua scaffolding templates (.lua files).
Built-in templates are used as fallback when a custom one is not found.
Accepts an absolute path or a path relative to the workspace root.