pub struct EmmyrcGmodHookMappings {
pub method_to_hook: HashMap<String, String>,
pub emitter_to_hook: HashMap<String, String>,
pub method_prefixes: Vec<String>,
}Fields
method_to_hook: HashMap<String, String>emitter_to_hook: HashMap<String, String>method_prefixes: Vec<String>Trait Implementations
Sourceimpl Clone for EmmyrcGmodHookMappings
impl Clone for EmmyrcGmodHookMappings
Sourcefn clone(&self) -> EmmyrcGmodHookMappings
fn clone(&self) -> EmmyrcGmodHookMappings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmmyrcGmodHookMappings
impl Debug for EmmyrcGmodHookMappings
Sourceimpl Default for EmmyrcGmodHookMappings
impl Default for EmmyrcGmodHookMappings
Sourcefn default() -> EmmyrcGmodHookMappings
fn default() -> EmmyrcGmodHookMappings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EmmyrcGmodHookMappings
impl<'de> Deserialize<'de> for EmmyrcGmodHookMappings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmmyrcGmodHookMappings
impl JsonSchema for EmmyrcGmodHookMappings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmmyrcGmodHookMappings
impl RefUnwindSafe for EmmyrcGmodHookMappings
impl Send for EmmyrcGmodHookMappings
impl Sync for EmmyrcGmodHookMappings
impl Unpin for EmmyrcGmodHookMappings
impl UnsafeUnpin for EmmyrcGmodHookMappings
impl UnwindSafe for EmmyrcGmodHookMappings